@@ -8,7 +8,6 @@ import hashlib as hash
 from Crypto.Cipher import AES
 from Crypto.Cipher import Blowfish
 from Crypto.Protocol.KDF import PBKDF2
-from random import randbytes
 
 
 class Ciphers:
@@ -32,30 +31,6 @@ class Ciphers:
 
     # misc functions
 
-    def sec_delete(self, file_path, random_fill = True, null_fill = True, passes = 35) -> int:
-        if "/home/" not in file_path or "/." in file_path:
-            return 1
-        else:
-            with open (file_path, "wb") as file:
-                data = file.read()
-            length = len(data)
-            if random_fill is True:
-                for _ in passes:
-                    with open(file_path, "wb") as file:
-                        file.write(randbytes(length))
-            if null_fill is True:
-                for _ in passes:
-                    with open (file_path, "wb") as file:
-                        file.write("\x00" * length)
-            return 0
-
-
-    def delete(self, path):
-        if '/home/' not in path or "/." in path:
-            return 1
-        else:
-            os.system("rm {}".format(path))
-
 
     def check_path_validity(self, path=str or None, decrypting=bool, type_=str) -> int:
         """
